=====================
Sage Combinat Widgets
=====================

Jupyter widgets for Sage Combinat

To use this module, you need to import it::

    from sage_combinat_widgets import *

This work is licensed under a `Creative Commons Attribution-Share Alike
3.0 License`__.

__ https://creativecommons.org/licenses/by-sa/3.0/

Sage Combinat Widgets
=====================

.. toctree::
   :maxdepth: 2
   :glob:

   grid_view_*
   *

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
